Module commands_patterns

Module commands_patterns 

Pattern listing functionality for oo patterns commands.

Functions

cmd_patterns
List patterns from both project-local and user config directories.
cmd_patterns_in
List learned pattern files from a single directory (legacy test helper).
list_patterns_in
Print pattern entries from a single directory, returning true if any were found.