Module learn

Module learn 

LLM-powered pattern learning.

Structs

LearnConfig
Configuration for the oo learn LLM integration.

Functions

learn_status_path
Path to the one-line status file written by the background learn process.
load_learn_config
Load learn configuration from ~/.config/oo/config.toml.
patterns_dir
Get the directory containing user-defined patterns.
run_background
Entry point for the background learn child process.
run_learn
Run the learn flow: call LLM, validate + save pattern.
spawn_background
Spawn the learning process in the background by re-exec’ing ourselves.