pub fn extract_summary(pat: &SuccessPattern, output: &str) -> Option<String>Expand description
Apply a success pattern to output, returning the formatted summary if it matches.
pub fn extract_summary(pat: &SuccessPattern, output: &str) -> Option<String>Apply a success pattern to output, returning the formatted summary if it matches.