pub struct FailurePattern {
pub strategy: FailureStrategy,
}Expand description
Strategy for filtering failed command output.
When a command exits with a non-zero status, the failure strategy extracts relevant error information (e.g., tail N lines, head N lines, grep for error keywords, or extract text between delimiters).
Fields
strategy: FailureStrategyThe strategy to apply for extracting error information.