project_id

Function project_id 

pub fn project_id() -> String
Get the project identifier for the current working directory.

Returns a unique identifier for the project, used to scope store operations. Attempts to detect from git remote URL, git root directory, or current directory name.