LLM-powered pattern learning.
Structs
- Learn
Config - Configuration for the
oo learnLLM integration.
Functions
- learn_
status_ path - Path to the one-line status file written by the background learn process.
- load_
learn_ config - Load learn configuration from
~/.config/oo/config.toml. - patterns_
dir - Get the directory containing user-defined patterns.
- run_
background - Entry point for the background learn child process.
- run_
learn - Run the learn flow: call LLM, validate + save pattern.
- spawn_
background - Spawn the learning process in the background by re-exec’ing ourselves.